# HeliumHelper

HeliumHelper is a Python library to aid in creating Helium apps.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install HeliumHelper.

```bash
pip install HeliumHelper
```

## Usage

```python
from heliumhelper import helpers

# returns current oracle price
helpers.get_current_price()
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)